Crate hardened_malloc

Crate hardened_malloc 

Structs

HardenedMalloc

Functions

aligned_alloc
calloc
free
free_sized
The free function with an extra parameter for passing the size requested at allocation time.
malloc
malloc_object_size
return an upper bound on object size for any pointer based on malloc metadata
malloc_object_size_fast
similar to malloc_object_size, but avoiding locking so the results are much more limited
posix_memalign
realloc